@@ -10,6 +10,6 @@ plot(out, type = "dotchart")
 plot(out, type = "distance")
 
 ## Detect outliers according to CJ
-ref <- group_extract(coda, "CJ")
+ref <- group_subset(coda, which = "CJ")
 out <- detect_outlier(coda, reference = ref, method = "mcd")
 plot(out, type = "dotchart")
